From 93540315719a0647d2f64a1eb6ee9d98bdd5fc60 Mon Sep 17 00:00:00 2001
From: Mark McDowall <mark@mcdowall.ca>
Date: Mon, 9 Oct 2023 21:00:05 -0700
Subject: [PATCH] Log executing health check

Towards #6076

(cherry picked from commit 78b39bd2fecda60e04a1fef17ae17f62bd2b6914)
---
 .../HealthCheck/HealthCheckService.cs             | 15 +++++++++++++--
 1 file changed, 13 insertions(+), 2 deletions(-)

diff --git a/src/NzbDrone.Core/HealthCheck/HealthCheckService.cs b/src/NzbDrone.Core/HealthCheck/HealthCheckService.cs
index c56a6559a..1d89dbec5 100644
--- a/src/NzbDrone.Core/HealthCheck/HealthCheckService.cs
+++ b/src/NzbDrone.Core/HealthCheck/HealthCheckService.cs
@@ -1,6 +1,7 @@
 using System;
 using System.Collections.Generic;
 using System.Linq;
+using NLog;
 using NzbDrone.Common.Cache;
 using NzbDrone.Common.EnvironmentInfo;
 using NzbDrone.Common.Messaging;
@@ -28,6 +29,7 @@ public class HealthCheckService : IHealthCheckService,
         private readonly IProvideHealthCheck[] _scheduledHealthChecks;
         private readonly Dictionary<Type, IEventDrivenHealthCheck[]> _eventDrivenHealthChecks;
         private readonly IEventAggregator _eventAggregator;
+        private readonly Logger _logger;
 
         private readonly ICached<HealthCheck> _healthCheckResults;
         private readonly HashSet<IProvideHealthCheck> _pendingHealthChecks;
@@ -40,10 +42,12 @@ public HealthCheckService(IEnumerable<IProvideHealthCheck> healthChecks,
                                   IEventAggregator eventAggregator,
                                   ICacheManager cacheManager,
                                   IDebounceManager debounceManager,
-                                  IRuntimeInfo runtimeInfo)
+                                  IRuntimeInfo runtimeInfo,
+                                  Logger logger)
         {
             _healthChecks = healthChecks.ToArray();
             _eventAggregator = eventAggregator;
+            _logger = logger;
 
             _healthCheckResults = cacheManager.GetCache<HealthCheck>(GetType());
             _pendingHealthChecks = new HashSet<IProvideHealthCheck>();
@@ -88,7 +92,14 @@ private void ProcessHealthChecks()
 
             try
             {
-                var results = healthChecks.Select(c => c.Check())
+                var results = healthChecks.Select(c =>
+                    {
+                        _logger.Trace("Check health -> {0}", c.GetType().Name);
+                        var result = c.Check();
+                        _logger.Trace("Check health <- {0}", c.GetType().Name);
+
+                        return result;
+                    })
                     .ToList();
 
                 foreach (var result in results)
